@@ -271,8 +271,6 @@ dzl_suggestion_entry_changed (GtkEditable *editable)
       DZL_GOTO (finish);
     }
 
-  g_signal_emit (self, signals [SHOW_SUGGESTIONS], 0);
-
   suggestion = dzl_suggestion_popover_get_selected (priv->popover);
 
   if (suggestion != NULL)
@@ -755,6 +753,8 @@ dzl_suggestion_entry_set_model (DzlSuggestionEntry *self,
       dzl_suggestion_popover_set_model (priv->popover, model);
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_MODEL]);
       dzl_suggestion_entry_update_attrs (self);
+
+      g_signal_emit (self, signals [SHOW_SUGGESTIONS], 0);
     }
 
   DZL_EXIT;
@@ -811,7 +811,10 @@ dzl_suggestion_entry_default_position_func (DzlSuggestionEntry *self,
                                             gboolean           *is_absolute,
                                             gpointer            user_data)
 {
+  GtkStyleContext *style_context;
   GtkAllocation alloc;
+  GtkStateFlags state;
+  GtkBorder margin;
 
   g_return_if_fail (DZL_IS_SUGGESTION_ENTRY (self));
   g_return_if_fail (area != NULL);
@@ -823,6 +826,15 @@ dzl_suggestion_entry_default_position_func (DzlSuggestionEntry *self,
 
   area->y += alloc.height;
   area->height = 300;
+
+  /* Adjust for bottom margin */
+  style_context = gtk_widget_get_style_context (GTK_WIDGET (self));
+  state = gtk_style_context_get_state (style_context);
+  gtk_style_context_get_margin (style_context, state, &margin);
+
+  area->y -= margin.bottom;
+  area->x += margin.left;
+  area->width -= margin.left + margin.right;
 }
 
 /**
