@@ -22,6 +22,8 @@
 
 #include <glib/gi18n.h>
 
+#include "dzl-debug.h"
+
 #include "animation/dzl-animation.h"
 #include "suggestions/dzl-suggestion.h"
 #include "suggestions/dzl-suggestion-entry.h"
@@ -772,20 +774,25 @@ dzl_suggestion_popover_items_changed (DzlSuggestionPopover *self,
                                       guint                 added,
                                       GListModel           *model)
 {
+  DZL_ENTRY;
+
   g_assert (DZL_IS_SUGGESTION_POPOVER (self));
   g_assert (G_IS_LIST_MODEL (model));
 
+  DZL_TRACE_MSG ("removed=%d, added=%d, requested=%d",
+                 removed, added, self->popup_requested);
+
   if (g_list_model_get_n_items (model) == 0)
     {
       dzl_suggestion_popover_popdown (self);
-      return;
+      DZL_EXIT;
     }
 
   if (self->popup_requested)
     {
       dzl_suggestion_popover_popup (self);
       self->popup_requested = FALSE;
-      return;
+      DZL_EXIT;
     }
 
   /*
@@ -807,6 +814,13 @@ dzl_suggestion_popover_items_changed (DzlSuggestionPopover *self,
                                          G_CALLBACK (dzl_suggestion_popover_notify_child_revealed),
                                          self);
     }
+  else
+    {
+      dzl_suggestion_popover_popup (self);
+      self->popup_requested = FALSE;
+    }
+
+  DZL_EXIT;
 }
 
 static void
